summaryrefslogtreecommitdiffstats
path: root/hosted-api/src/main/java/ai/vespa/hosted/api/Properties.java
diff options
context:
space:
mode:
Diffstat (limited to 'hosted-api/src/main/java/ai/vespa/hosted/api/Properties.java')
-rw-r--r--hosted-api/src/main/java/ai/vespa/hosted/api/Properties.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/hosted-api/src/main/java/ai/vespa/hosted/api/Properties.java b/hosted-api/src/main/java/ai/vespa/hosted/api/Properties.java
index 68656f06d7d..c0fe2074809 100644
--- a/hosted-api/src/main/java/ai/vespa/hosted/api/Properties.java
+++ b/hosted-api/src/main/java/ai/vespa/hosted/api/Properties.java
@@ -61,8 +61,8 @@ public class Properties {
return getNonBlankProperty("dataPlaneCertificateFile").map(Paths::get);
}
- /** Returns the path of the data plane private key file, if this is set with the 'dataPlanePrivateKeyFile' property. */
- public static Optional<Path> dataPlanePrivateKeyFile() {
+ /** Returns the path of the data plane private key file, if this is set with the 'dataPlaneKeyFile' property. */
+ public static Optional<Path> dataPlaneKeyFile() {
return getNonBlankProperty("dataPlaneKeyFile").map(Paths::get);
}